;; Generated package description from mmm-mode.el  -*- no-byte-compile: t -*-
(define-package "mmm-mode" "0.5.9.0.20221027.234010" "Allow Multiple Major Modes in a buffer" '((emacs "25.1") (cl-lib "0.2")) :commit "3c2071347a48a5aa172671687b0a3972381dc7d7" :authors '(("Michael Abraham Shulman" . "viritrilbia@gmail.com")) :maintainer '("Dmitry Gutov" . "dgutov@yandex.ru") :keywords '("convenience" "faces" "languages" "tools") :url "https://github.com/purcell/mmm-mode")
